@@ -8,7 +8,7 @@ use MarpaX::Languages::M4::Impl::Default;
 class MarpaX::Languages::M4 {
     extends 'MarpaX::Languages::M4::Impl::Default';
 
-    our $VERSION = '0.008'; # VERSION
+    our $VERSION = '0.009'; # VERSION
 
     our $AUTHORITY = 'cpan:JDDPAUSE'; # AUTHORITY
 
@@ -50,7 +50,7 @@ MarpaX::Languages::M4 - M4 pre-processor
 
 =head1 VERSION
 
-version 0.008
+version 0.009
 
 =head1 SYNOPSIS
 
@@ -80,25 +80,6 @@ This package is an implementation of M4.
 
 L<Marpa::R2>, L<Moops>, L<M4 POSIX|http://pubs.opengroup.org/onlinepubs/9699919799/utilities/m4.html>, L<M4 GNU|https://www.gnu.org/software/m4/manual/m4.html>
 
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
-
-=head1 SUPPORT
-
-=head2 Bugs / Feature Requests
-
-Please report any bugs or feature requests through the issue tracker
-at L<https://rt.cpan.org/Public/Dist/Display.html?Name=MarpaX-Languages-M4>.
-You will be notified automatically of any progress on your issue.
-
-=head2 Source Code
-
-This is open source software.  The code repository is available for
-public review and contribution under the terms of the license.
-
-L<https://github.com/jddurand/marpax-languages-m4>
-
-  git clone git://github.com/jddurand/marpax-languages-m4.git
-
 =head1 AUTHOR
 
 Jean-Damien Durand <jeandamiendurand@free.fr>
